@@ -41,7 +41,7 @@ import conda_build.noarch_python as noarch_python
 if sys.platform == "win32":
     import conda_build.windows as windows
 
-from boa.core.utils import shell_path
+from boa.core.utils import shell_path, get_sys_vars_stubs
 from boa.core.recipe_handling import copy_recipe
 
 from conda_build.build import (
@@ -126,6 +126,7 @@ def create_info_files(m, files, prefix):
             if src.get("git_url"):
                 source.git_info(
                     os.path.join(m.config.work_dir, src.get("folder", "")),
+                    build_prefix=m.config.build_prefix,
                     verbose=m.config.verbose,
                     fo=fo,
                 )
@@ -362,6 +363,12 @@ def write_build_scripts(m, script, build_file):
     with utils.path_prepended(m.config.host_prefix):
         with utils.path_prepended(m.config.build_prefix):
             env = environ.get_dict(m=m)
+
+    sysvars = get_sys_vars_stubs(env["target_platform"])
+    for s in sysvars:
+        if s not in env and s in m.config.variant:
+            env[s] = m.config.variant[s]
+
     env.update(m.build_features())
 
     env["CONDA_BUILD_STATE"] = "BUILD"
@@ -578,7 +585,7 @@ def build(m, stats=None, from_interactive=False, allow_interactive=False):
             stats = {}
 
         if m.skip():
-            console.print(utils.get_skip_message(m))
+            # console.print(utils.get_skip_message(m))
             return {}
 
         with utils.path_prepended(m.config.build_prefix):
@@ -632,5 +639,6 @@ def build(m, stats=None, from_interactive=False, allow_interactive=False):
             import asyncio
 
             asyncio.run(tui.enter_tui(m))
-
-        # exit(1)
+        else:
+            console.print("[red]ERROR: Build failed!")
+            exit(1)
